summaryrefslogtreecommitdiffstats
path: root/libkdeedu/kdeeduplot
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commiteb570158698cf61dad4f77d950ef908160f6c3cc (patch)
tree649bf182bcf0a20bed5035d25ffd77de5aee138a /libkdeedu/kdeeduplot
parentd8762de95349dc6edaa34db9bf699b367c1af6b1 (diff)
downloadtdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.tar.gz
tdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdeedu/kdeeduplot')
-rw-r--r--libkdeedu/kdeeduplot/kplotwidget.cpp6
-rw-r--r--libkdeedu/kdeeduplot/kplotwidget.h4
2 files changed, 5 insertions, 5 deletions
diff --git a/libkdeedu/kdeeduplot/kplotwidget.cpp b/libkdeedu/kdeeduplot/kplotwidget.cpp
index 22fba3b0..5f13de6e 100644
--- a/libkdeedu/kdeeduplot/kplotwidget.cpp
+++ b/libkdeedu/kdeeduplot/kplotwidget.cpp
@@ -23,8 +23,8 @@
#include "kplotwidget.h"
#include "kplotwidget.moc"
-KPlotWidget::KPlotWidget( double x1, double x2, double y1, double y2, TQWidget *tqparent, const char* name )
- : TQWidget( tqparent, name, WNoAutoErase ),
+KPlotWidget::KPlotWidget( double x1, double x2, double y1, double y2, TQWidget *parent, const char* name )
+ : TQWidget( parent, name, WNoAutoErase ),
dXtick(0.0), dYtick(0.0),
nmajX(0), nminX(0), nmajY(0), nminY(0),
ShowTickMarks( true ), ShowTickLabels( true ), ShowGrid( false )
@@ -223,7 +223,7 @@ void KPlotWidget::drawObjects( TQPainter *p ) {
double KPlotWidget::dmod( double a, double b ) { return ( b * ( ( a / b ) - int( a / b ) ) ); }
void KPlotWidget::drawBox( TQPainter *p ) {
- //First, fill in padding region with bgColor() to tqmask out-of-bounds plot data
+ //First, fill in padding region with bgColor() to mask out-of-bounds plot data
p->setPen( bgColor() );
p->setBrush( bgColor() );
diff --git a/libkdeedu/kdeeduplot/kplotwidget.h b/libkdeedu/kdeeduplot/kplotwidget.h
index 27bd15a0..c886bbaf 100644
--- a/libkdeedu/kdeeduplot/kplotwidget.h
+++ b/libkdeedu/kdeeduplot/kplotwidget.h
@@ -47,10 +47,10 @@ public:
*@param x2 the maximum X value in data units
*@param y1 the minimum Y value in data units
*@param y2 the maximum Y value in data units
*@param tqparent the tqparent widget
*@param name name label for the KPlotWidget
*/
- KPlotWidget( double x1=0.0, double x2=1.0, double y1=0.0, double y2=1.0, TQWidget *tqparent=0, const char* name=0 );
+ KPlotWidget( double x1=0.0, double x2=1.0, double y1=0.0, double y2=1.0, TQWidget *parent=0, const char* name=0 );
/**Destructor (empty)
*/
@@ -47,10 +47,10 @@ public:
*@param y1 the minimum Y value in data units
*@param y2 the maximum Y value in data units
- *@param tqparent the tqparent widget
+ *@param parent the parent widget
*@param name name label for the KPlotWidget
*/